/*
 * vip1710device.h: 
 *
 * See the README file for copyright information and how to reach the author.
 *
 */

#ifndef __VIP1710_DEVICE_H
#define __VIP1710_DEVICE_H
#include <vdr/device.h>
#include <vdr/thread.h>
#include <vdr/plugin.h>
#include <directfb.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <sys/stat.h>
#include <unistd.h>
#include "vip1710osd.h"
#include "vip1710player.h"

#define DFBCHECK(x...)                                         \
  {                                                            \
    DFBResult err = x;                                         \
                                                               \
    if (err != DFB_OK)                                         \
      {                                                        \
        fprintf( stderr, "%s <%d>:\n\t", __FILE__, __LINE__ ); \
        DirectFBErrorFatal( #x, err );                         \
      }                                                        \
  }

typedef enum {
  undef,
  video,
  audio_only
} eStreamtype;

class cVip1710Device: public cDevice {
private:
	int		fd_server;
	int		fd_out;
	struct sockaddr_un fd_addr;

	IDirectFB	*dfb;
	IDirectFBSurface *dfb_primary;

	cVip1710Player	*m_Player;
	cSpuDecoder	*spuDecoder;

	int64_t		last_pts;

	bool		current_VideoFormat16_9;
	eVideoDisplayFormat current_VideoDisplayFormat;
	ePlayMode	current_PlayMode;
	int		current_Width;
	int		current_Height;
	int		current_AspectRatio;

	void OpenFramebuffer();
	int WriteMPEGStream(const uchar *Data, int Length, int TimeoutMs = 0, int RetryMs = 0);
	void UpdateTsVideoMeta(const uchar *Data, int Length);
	void UpdatePesVideoMeta(const uchar *Data, int Length);
	bool WaitForClient();

public:
	cVip1710Device(void);
	~cVip1710Device();
	static cVip1710Device* GetInstance();
	void MakePrimaryDevice(bool On);
	virtual bool HasDecoder(void) const;
	virtual bool CanReplay(void) const;
	virtual bool SetPlayMode(ePlayMode PlayMode);
	virtual void TrickSpeed(int Speed);
	virtual void Clear(void);
	virtual void Play(void);
	virtual void Freeze(void);
	virtual void Mute(void);
        virtual int GetAudioChannelDevice(void);
	virtual void SetAudioChannelDevice(int AudioChannel);
	virtual int PlayVideo(const uchar *Data, int Length);
	virtual int PlayAudio(const uchar *Data, int Length, uchar Id);
	virtual int PlayTs(const uchar *Data, int Length, bool VideoOnly);
	virtual int PlayTsVideo(const uchar *Data, int Length);
	virtual int PlayTsAudio(const uchar *Data, int Length);
	virtual void SetVideoDisplayFormat(eVideoDisplayFormat VideoDisplayFormat);
	virtual void SetVideoFormat(bool VideoFormat16_9);
	virtual void UpdateVideoMeta();
	virtual void SetVolumeDevice(int Volume);
#if APIVERSNUM >= 10708
	virtual void GetVideoSize(int &Width, int &Height, double &VideoAspect);
	virtual void GetOsdSize(int &Width, int &Height, double &PixelAspect);
#endif
	virtual bool Poll(cPoller &Poller, int TimeoutMs = 0);
	virtual cSpuDecoder *GetSpuDecoder(void);
	virtual int64_t GetSTC(void);
};
#endif
