/*
	Copyright (C) 2010 Hans-Werner Hilse <hilse@web.de>
	See file "COPYING" for licence information.
*/
#ifndef __IPCSTACK_PROTOTYPES
#define __IPCSTACK_PROTOTYPES

#include "vipipc.h"

/*******************************************************************************
* IPC PROTOTYPES:
*******************************************************************************/

/* NameService
 *
 * manages object/service <-> socket name associations
 */

/* NameService_new(char *socketname) */
IPCPROTO_NEW_GENERIC_D(NameService)
/* NameService_LookupObject(c, char* objectname, char** value) */
/*  ret: 250: not found */
IPCPROTO_NEW_CALL_D(NameService, LookupObject)


/* InformationService
 *
 * Interface for aquiring config/status info from a DB daemon (infobroker)
 */

/* InformationService_new(ipcconn nameservice) */
IPCPROTO_NEW_SERVICE_D(InformationService)
/* InformationService_GetObject(c, const char* object, char** value) */
IPCPROTO_NEW_CALL_D(InformationService, GetObject)
/* InformationService_SetObject(c, const char* object, const char* value, int store) */
IPCPROTO_NEW_CALL_D(InformationService, SetObject)
/* InformationService_UnsetObject(c, const char* object, int store) */
IPCPROTO_NEW_CALL_D(InformationService, UnsetObject)
/* InformationService_SubscribeObject(c, const char* object, int store, const char* socketname) */
IPCPROTO_NEW_CALL_D(InformationService, SubscribeObject)
/* InformationService_SubscribeObjectInternal(c, const char* object, const char* socketname) */
IPCPROTO_NEW_CALL_D(InformationService, SubscribeObjectInternal)


/* InformationObserver
 *
 * Interface for receiving notifications for objects
 * subscribed at an InformationService
 */

/* InformationObserver_new(char* socketname) */
IPCPROTO_NEW_SERVER_D(InformationObserver)
/* InformationObserver_parse_OnObjectsChanged(msg, int* store, char** object) */
IPCPROTO_NEW_PARSER_D(InformationObserver, OnObjectsChanged)
/* InformationObserver_dispatch_OnObjectsChanged(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(InformationObserver, OnObjectsChanged)
/* InformationObserver_parse_OnObjectsRemoved(msg, int* store, char** object) */
IPCPROTO_NEW_PARSER_D(InformationObserver, OnObjectsRemoved)
/* InformationObserver_dispatch_OnObjectsRemoved(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(InformationObserver, OnObjectsRemoved)


/* ApplicationService
 *
 * Interface to appman, in order to register new applications
 * and activate them, as well as for applications in order
 * to notify their startup and report on pings.
 */

/* ApplicationService_new(ipcconn nameservice) */
IPCPROTO_NEW_SERVICE_D(ApplicationService)
/* ApplicationService_RegisterApplication(c, const char* xml_app_config_file) */
IPCPROTO_NEW_CALL_D(ApplicationService, RegisterApplication)
/* ApplicationService_ReportStarted(c, int application_id, const char* appsocket) */
/*  appsocket must be the socketname (with "#<n>") for an Application server */
IPCPROTO_NEW_CALL_D(ApplicationService, ReportStarted)
/* ApplicationService_ReportPing(c, int application_id) */
IPCPROTO_NEW_CALL_D(ApplicationService, ReportPing)
/* ApplicationService_Activate(c, int application_id) */
IPCPROTO_NEW_CALL_D(ApplicationService, Activate)
/* ApplicationService_Kill(c, int application_id) */
IPCPROTO_NEW_CALL_D(ApplicationService, Kill)


/* Application
 *
 * Interface for receiving notifications from appman,
 * every application needs to register itself after startup
 * to appman and has to provide an Application interface
 * as argument (see ApplicationService_ReportStarted)
 */

/* Application_new(char* socketname) */
IPCPROTO_NEW_SERVER_D(Application)
/* Application_parse_LoadUri(msg, char** mime, char** uri, int* is_stacked) */
IPCPROTO_NEW_PARSER_D(Application, LoadUri)
/* Application_dispatch_LoadUri(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(Application, LoadUri)
/* Application_parse_ChangeState(msg, int* new_state) */
IPCPROTO_NEW_PARSER_D(Application, ChangeState)
/* Application_dispatch_ChangeState(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(Application, ChangeState)
/* Application_dispatch_Ping(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(Application, Ping)


/* UriLoaderService
 *
 * Allows to trigger URI based application startups in appman
 */

/* UriLoaderService_new(ipcconn nameservice) */
IPCPROTO_NEW_SERVICE_D(UriLoaderService)
/* UriLoaderService_LoadUri(c, const char* uri, const char* mime) */
IPCPROTO_NEW_CALL_D(UriLoaderService, LoadUri)


/* VolumeService
 *
 * allows to get/set volume and mute
 */

/* VolumeService_new(ipcconn nameservice) */
IPCPROTO_NEW_SERVICE_D(VolumeService)
/* VolumeService_GetVolume(c, int* volume) */
IPCPROTO_NEW_CALL_D(VolumeService, GetVolume)
/* VolumeService_SetVolume(c, int volume) */
IPCPROTO_NEW_CALL_D(VolumeService, SetVolume)
/* VolumeService_IsMuted(c, int* ismuted) */
IPCPROTO_NEW_CALL_D(VolumeService, IsMuted)
/* VolumeService_Mute(c, int mute) */
IPCPROTO_NEW_CALL_D(VolumeService, Mute)


/* MediaService
 *
 * Create MediaPlayer instances
 */

/* MediaService_new(ipcconn nameservice) */
IPCPROTO_NEW_SERVICE_D(MediaService)
/* MediaService_CreatePlayerInstance(c, int application_id, const char* socketname) */
/*  socketname must contain the name of a socket for a MediaPlayerObserver server */
IPCPROTO_NEW_CALL_D(MediaService, CreatePlayerInstance)
/* MediaService_GetActivePlayerStatusInterface(c, int application_id, const char* socketname) */
/*  not sure about this, yet. ActiveMediaPlayerStatusObserver interface? */
IPCPROTO_NEW_CALL_D(MediaService, GetActivePlayerStatusInterface)


/* MediaPlayerObserver
 *
 * Will get notified by MediaPlayer instance upon status changes etc.
 */

/* MediaPlayerObserver_new(char* socketname) */
IPCPROTO_NEW_SERVER_D(MediaPlayerObserver)
/* MediaPlayerObserverBase_new(char* socketname) */
/*  NOTE: you should use only one of these, it will get called with both interfaces. */
IPCPROTO_NEW_SERVER_D(MediaPlayerObserverBase)
/* MediaPlayerObserver_parse_OnMediaPlayerInitialized(msg, char** socketname) */
IPCPROTO_NEW_PARSER_D(MediaPlayerObserver, OnMediaPlayerInitialized)
/* MediaPlayerObserver_dispatch_OnMediaPlayerInitialized(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(MediaPlayerObserver, OnMediaPlayerInitialized)
/* MediaPlayerObserverBase_parse_OnStateChanged(msg, char** state_name, int* state) */
IPCPROTO_NEW_PARSER_D(MediaPlayerObserverBase, OnStateChanged)
/* MediaPlayerObserverBase_dispatch_OnStateChanged(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(MediaPlayerObserverBase, OnStateChanged)
/* MediaPlayerObserverBase_parse_OnPositionChanged(msg, int* pos1, int* pos2) */
IPCPROTO_NEW_PARSER_D(MediaPlayerObserverBase, OnPositionChanged)
/* MediaPlayerObserverBase_dispatch_OnPositionChanged(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(MediaPlayerObserverBase, OnPositionChanged)
/* MediaPlayerObserverBase_parse_OnDataAvailable(msg, int* data_available) */
IPCPROTO_NEW_PARSER_D(MediaPlayerObserverBase, OnDataAvailable)
/* MediaPlayerObserverBase_dispatch_OnDataAvailable(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(MediaPlayerObserverBase, OnDataAvailable)
/* MediaPlayerObserverBase_dispatch_OnStreamInfoChanged(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(MediaPlayerObserverBase, OnStreamInfoChanged)
/* MediaPlayerObserverBase_parse_OnAudioStreamInfoChanged(msg, int* id1, int* id2, int* is_stacked) */
IPCPROTO_NEW_PARSER_D(MediaPlayerObserverBase, OnAudioStreamInfoChanged)
/* MediaPlayerObserverBase_dispatch_OnAudioStreamInfoChanged(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(MediaPlayerObserverBase, OnAudioStreamInfoChanged)
/* MediaPlayerObserverBase_parse_OnActiveAudioStreamChanged(msg, int* id1, int* id2, int* is_stacked) */
IPCPROTO_NEW_PARSER_D(MediaPlayerObserverBase, OnActiveAudioStreamChanged)
/* MediaPlayerObserverBase_dispatch_OnActiveAudioStreamChanged(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(MediaPlayerObserverBase, OnActiveAudioStreamChanged)
/* MediaPlayerObserverBase_parse_OnVideoStreamInfoChanged(msg, int* id1, int* id2, int* is_stacked) */
IPCPROTO_NEW_PARSER_D(MediaPlayerObserverBase, OnVideoStreamInfoChanged)
/* MediaPlayerObserverBase_dispatch_OnVideoStreamInfoChanged(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(MediaPlayerObserverBase, OnVideoStreamInfoChanged)
/* MediaPlayerObserverBase_parse_OnActiveVideoStreamChanged(msg, int* id1, int* id2, int* is_stacked) */
IPCPROTO_NEW_PARSER_D(MediaPlayerObserverBase, OnActiveVideoStreamChanged)
/* MediaPlayerObserverBase_dispatch_OnActiveVideoStreamChanged(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(MediaPlayerObserverBase, OnActiveVideoStreamChanged)
/* MediaPlayerObserverBase_parse_OnSubtitleStreamInfoChanged(msg, int* id1, int* id2, int* is_stacked) */
IPCPROTO_NEW_PARSER_D(MediaPlayerObserverBase, OnSubtitleStreamInfoChanged)
/* MediaPlayerObserverBase_dispatch_OnSubtitleStreamInfoChanged(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(MediaPlayerObserverBase, OnSubtitleStreamInfoChanged)
/* MediaPlayerObserverBase_parse_OnActiveSubtitleStreamChanged(msg, int* id1, int* id2, int* is_stacked) */
IPCPROTO_NEW_PARSER_D(MediaPlayerObserverBase, OnActiveSubtitleStreamChanged)
/* MediaPlayerObserverBase_dispatch_OnActiveSubtitleStreamChanged(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(MediaPlayerObserverBase, OnActiveSubtitleStreamChanged)
/* MediaPlayerObserverBase_parse_OnTeletextStreamInfoChanged(msg, int* id1, int* id2, int* is_stacked) */
IPCPROTO_NEW_PARSER_D(MediaPlayerObserverBase, OnTeletextStreamInfoChanged)
/* MediaPlayerObserverBase_dispatch_OnTeletextStreamInfoChanged(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(MediaPlayerObserverBase, OnTeletextStreamInfoChanged)
/* MediaPlayerObserverBase_parse_OnActiveTeletextStreamChanged(msg, int* id1, int* id2, int* is_stacked) */
IPCPROTO_NEW_PARSER_D(MediaPlayerObserverBase, OnActiveTeletextStreamChanged)
/* MediaPlayerObserverBase_dispatch_OnActiveTeletextStreamChanged(if,proc,m,handler(),d) */
IPCPROTO_NEW_DISPATCHER_D(MediaPlayerObserverBase, OnActiveTeletextStreamChanged)


/* MediaPlayer
 *
 * Control interface for MediaPlayer instances, as created
 * by the MediaService
 */

/* MediaPlayer_new(char *socketname) */
IPCPROTO_NEW_GENERIC_D(MediaPlayer)
/* MediaPlayer_Activate(c) */
IPCPROTO_NEW_CALL_D(MediaPlayer, Activate)
/* MediaPlayer_Open(c, const char* uri) */
IPCPROTO_NEW_CALL_D(MediaPlayer, Open)
/* MediaPlayer_Play(c) */
IPCPROTO_NEW_CALL_D(MediaPlayer, Play)
/* MediaPlayer_Pause(c) */
IPCPROTO_NEW_CALL_D(MediaPlayer, Pause)
/* MediaPlayer_Rewind(c) */
IPCPROTO_NEW_CALL_D(MediaPlayer, Rewind)
/* MediaPlayer_FastForward(c) */
IPCPROTO_NEW_CALL_D(MediaPlayer, FastForward)
/* MediaPlayer_Close(c) */
IPCPROTO_NEW_CALL_D(MediaPlayer, Close)
/* MediaPlayer_ReleaseInstance(c) */
IPCPROTO_NEW_CALL_D(MediaPlayer, ReleaseInstance)
/* MediaPlayer_SetActiveAudioStream(c, int stream_id) */
IPCPROTO_NEW_CALL_D(MediaPlayer, SetActiveAudioStream)
/* MediaPlayer_SetActiveVideoStream(c, int stream_id) */
IPCPROTO_NEW_CALL_D(MediaPlayer, SetActiveVideoStream)
/* MediaPlayer_SetActiveSubtitleStream(c, int stream_id) */
IPCPROTO_NEW_CALL_D(MediaPlayer, SetActiveSubtitleStream)
/* MediaPlayer_SetActiveTeletextStream(c, int stream_id) */
IPCPROTO_NEW_CALL_D(MediaPlayer, SetActiveTeletextStream)
/* MediaPlayer_SetMacrovision(c, int flag_macrovision) */
IPCPROTO_NEW_CALL_D(MediaPlayer, SetMacrovision)


/* MediaPlayerStatus
 *
 * Queries status information from a running MediaPlayer
 * instance
 */

/* MediaPlayerStatus_new(char *socketname) */
IPCPROTO_NEW_GENERIC_D(MediaPlayerStatus)
/* MediaPlayerStatus_GetPosition(c, int* pos) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetPosition)
/* MediaPlayerStatus_GetCapabilities(c, int* capabilities) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetCapabilities)
/* MediaPlayerStatus_GetState(c, int* state) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetState)
/* MediaPlayerStatus_GetUrl(c, char** uri) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetUrl)
/* MediaPlayerStatus_GetMacrovision(c, int* flag_macrovision) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetMacrovision)
/* MediaPlayerStatus_GetActiveVideoStream(c, int* stream_id) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetActiveVideoStream)
/* MediaPlayerStatus_GetActiveAudioStream(c, int* stream_id) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetActiveAudioStream)
/* MediaPlayerStatus_GetActiveSubtitleStream(c, int* stream_id) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetActiveSubtitleStream)
/* MediaPlayerStatus_GetActiveTeletextStream(c, int* stream_id) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetActiveTeletextStream)
/* MediaPlayerStatus_GetStreamInfo(c, ipcmessage* reply) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetStreamInfo)
/* MediaPlayerStatus_GetAudioStreamInfo(c, int stream_id, ipcmessage* reply) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetAudioStreamInfo)
/* MediaPlayerStatus_GetVideoStreamInfo(c, int stream_id, ipcmessage* reply) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetVideoStreamInfo)
/* MediaPlayerStatus_GetSubtitleStreamInfo(c, int stream_id, ipcmessage* reply) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetSubtitleStreamInfo)
/* MediaPlayerStatus_GetTeletextStreamInfo(c, int stream_id, ipcmessage* reply) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetTeletextStreamInfo)
/* MediaPlayerStatus_GetParameter(c, const char* parameter, char** value) */
IPCPROTO_NEW_CALL_D(MediaPlayerStatus, GetParameter)


/* VideoMixerService
 *
 * Aquire VideoMixer instances
 */

/* VideoMixerService_new(ipcconn nameservice) */
IPCPROTO_NEW_SERVICE_D(VideoMixerService)
/* VideoMixerService_GetInstance(c, int application_id, char** socketname) */
IPCPROTO_NEW_CALL_D(VideoMixerService, GetInstance)


/* VideoMixer
 *
 * Controls a VideoMixer instance as aquired from
 * VideoMixerService
 */

/* VideoMixer_new(char *socketname) */
IPCPROTO_NEW_GENERIC_D(VideoMixer)
/* VideoMixer_SetVideoWindow(c, int x, int y, int width, int height) */
IPCPROTO_NEW_CALL_D(VideoMixer, SetVideoWindow)
/* VideoMixer_SetFullVideoWindow(c) */
IPCPROTO_NEW_CALL_D(VideoMixer, SetFullVideoWindow)
/* VideoMixer_EnableVideoWindow(c, int enable) */
IPCPROTO_NEW_CALL_D(VideoMixer, EnableVideoWindow)
/* VideoMixer_SetVideoFrame(c, int x, int y, int width, int height) */
IPCPROTO_NEW_CALL_D(VideoMixer, SetVideoFrame)
/* VideoMixer_SetFullVideoFrame(c) */
IPCPROTO_NEW_CALL_D(VideoMixer, SetFullVideoFrame)
/* VideoMixer_SetAlphaWindowColorKeyMode(c, int windowid, int colorkeymode) */
IPCPROTO_NEW_CALL_D(VideoMixer, SetAlphaWindowColorKeyMode)
/* VideoMixer_SetAlphaWindowPosition(c, int windowid, int x, int y, int width, int height) */
IPCPROTO_NEW_CALL_D(VideoMixer, SetAlphaWindowPosition)
/* VideoMixer_SetAlphaWindowSolidColor(c, int windowid, int colorvalue) */
IPCPROTO_NEW_CALL_D(VideoMixer, SetAlphaWindowSolidColor)
/* VideoMixer_SetAlphaWindowTransparency(c, int windowid, int transparency) */
IPCPROTO_NEW_CALL_D(VideoMixer, SetAlphaWindowTransparency)
/* VideoMixer_EnableAlphaWindow(c, int windowid, int enable) */
IPCPROTO_NEW_CALL_D(VideoMixer, EnableAlphaWindow)
/* VideoMixer_SetColorKey(c, int colorkey) */
IPCPROTO_NEW_CALL_D(VideoMixer, SetColorKey)
/* VideoMixer_EnableWideScreen(c, int enable_wss) */
IPCPROTO_NEW_CALL_D(VideoMixer, EnableWideScreen)



#endif /* __IPCSTACK_PROTOTYPES */
